@@ -54,10 +54,10 @@ class ProphecyBuildTool:
                 path_pipeline_absolute)
 
             self.pipelines_build_path[path_pipeline] = None
-
+            self._process_sequential([self.process(['ls -ltraR'], path_pipeline_absolute, is_shell=True)])
             if rc == 0:
                 if (self.project_language == 'python'):
-                    path_pipeline_dist = path_pipeline_absolute + '/dist'
+                    path_pipeline_dist = path_pipeline_absolute + '/distrib'
                     for path_pipeline_build in os.listdir(path_pipeline_dist):
                         path_pipeline_build_absolute = path_pipeline_dist + '/' + path_pipeline_build
                         if os.path.isfile(path_pipeline_build_absolute) and path_pipeline_build.endswith('.whl'):
@@ -78,6 +78,8 @@ class ProphecyBuildTool:
                                 'uploaded': False
                             }
 
+                print("\n[bold red]ls -ltraR just before end.[/bold red]")
+                self._process_sequential([self.process(['ls -ltraR'], path_pipeline_absolute, is_shell=True)])
                 print("\n[bold blue]✅ Build complete![/bold blue]")
             else:
                 print("\n[bold red]❌ Build failed![/bold red]")
@@ -91,16 +93,12 @@ class ProphecyBuildTool:
                 # Check for compilation errors
                 self.process(['python', '-m', 'compileall', '.', '-q'], path_pipeline_absolute),
                 # Generate wheel
-                self.process(['python', 'setup.py', 'bdist_wheel'], path_pipeline_absolute),
-                self.process(['ls -ltra'], path_pipeline_absolute, is_shell=True)
+                self.process(['python', 'setup.py', 'bdist_wheel', f'--dist-dir distrib/'], path_pipeline_absolute)
             ]
         )
 
     def build_scala(self, path_pipeline_absolute):
-        return self._process_communicate(
-            subprocess.Popen(['mvn', 'clean', 'package', '-q', '-DskipTests'], stdout=subprocess.PIPE,
-                             stderr=subprocess.PIPE,
-                             cwd=path_pipeline_absolute))
+        return self.process(['mvn', 'clean', 'package', '-q', '-DskipTests'], path_pipeline_absolute)
 
     def deploy(self):
         self.build()
@@ -252,7 +250,7 @@ class ProphecyBuildTool:
 
     def _process_sequential(self, subprocesses):
         for process in subprocesses:
-            rc = self._process_communicate(process)
+            rc = process.returncode
             print("Command: " + str(rc))
             if rc != 0:
                 break
@@ -260,7 +258,7 @@ class ProphecyBuildTool:
         return rc
 
     def process(self, process_args, cwd, std_output=subprocess.PIPE, std_input=subprocess.PIPE, is_shell=False):
-        return subprocess.Popen(process_args, stdout=std_output, stderr=std_input, shell=is_shell, cwd=cwd)
+        return subprocess.run(process_args, stdout=std_output, stderr=std_input, shell=is_shell, cwd=cwd)
 
     @classmethod
     def _verify_databricks_configs(cls):
